# Changelog

```{image} https://raw.githubusercontent.com/dmedina559/bedrock-server-manager/main/src/bedrock_server_manager/web/static/image/icon/favicon.svg
:alt: Bedrock Server Manager Icon
:width: 200px
:align: center
```
---

```{note}
   **Format Change:** As of version 3.7.2, we have moved to automated changelog generation.
   Detailed implementation notes are now located within the linked GitHub Pull Requests.
```
---

```{changelog}
:changelog-url: https://bedrock-server-manager.readthedocs.io/en/latest/changelog.html
:github: https://github.com/DMedina559/bedrock-server-manager/releases/
:pypi: https://pypi.org/project/bedrock-server-manager/
```
---
